@@ -5,7 +5,7 @@
 import time
 
 from scrapy import signals
-from selenium import webdriver
+from seleniumwire import webdriver
 from selenium_stealth import stealth
 from scrapy.exceptions import NotConfigured
 from selenium.webdriver.common.by import By
@@ -15,6 +15,16 @@ from selenium.webdriver.support.wait import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
 
 
+def get_interceptor(headers):
+    def interceptor(request):
+        if request.url.startswith('https://collector-pxu6b0qd2s.px-cloud.net'):
+            request.abort()
+        for header in headers:
+            del request.headers[header.decode('utf-8').lower()]
+            request.headers[header.decode('utf-8').lower()] = headers[header].decode('utf-8')
+    return interceptor
+
+
 class SeleniumDownloaderMiddleware:
     """Scrapy middleware handling the requests using selenium"""
 
@@ -81,14 +91,8 @@ class SeleniumDownloaderMiddleware:
         return middleware
 
     def process_request(self, request, spider):
-        for cookie_name, cookie_value in request.cookies.items():
-            self.driver.add_cookie(
-                {
-                    'name': cookie_name,
-                    'value': cookie_value
-                }
-            )
-
+        self.driver.proxy = {'http': 'http://172.31.16.31:3128'}
+        self.driver.request_interceptor = get_interceptor(request.headers)
         self.driver.get(request.url)
 
         if "wait_text_to_be_present" in request.meta:
